[Xfce4-commits] <thunar:master> Use seconds timer to flush user manager.

Nick Schermer noreply at xfce.org
Tue Oct 30 22:06:13 CET 2012


Updating branch refs/heads/master
         to 987202b718b167b84b564670b6f8867910860d50 (commit)
       from 0fcc2f2dff3303f34d4a80dd691f67efa118e1e3 (commit)

commit 987202b718b167b84b564670b6f8867910860d50
Author: Nick Schermer <nick at xfce.org>
Date:   Tue Oct 30 21:25:36 2012 +0100

    Use seconds timer to flush user manager.

 thunar/thunar-user.c |   10 +++++-----
 1 files changed, 5 insertions(+), 5 deletions(-)

diff --git a/thunar/thunar-user.c b/thunar/thunar-user.c
index f56704c..184e575 100644
--- a/thunar/thunar-user.c
+++ b/thunar/thunar-user.c
@@ -54,8 +54,8 @@
 
 
 
 /* the interval in which the user/group cache is flushed (in ms) */
 #define THUNAR_USER_MANAGER_FLUSH_INTERVAL (10 * 60 * 1000)
 
 
 
@@ -521,9 +521,9 @@ thunar_user_manager_init (ThunarUserManager *manager)
 #endif
 
   /* start the flush timer */
-  manager->flush_timer_id = g_timeout_add_full (G_PRIORITY_LOW, THUNAR_USER_MANAGER_FLUSH_INTERVAL,
-                                                thunar_user_manager_flush_timer, manager,
-                                                thunar_user_manager_flush_timer_destroy);
+  manager->flush_timer_id = g_timeout_add_seconds_full (G_PRIORITY_LOW, THUNAR_USER_MANAGER_FLUSH_INTERVAL,
+                                                        thunar_user_manager_flush_timer, manager,
+                                                        thunar_user_manager_flush_timer_destroy);
 }
 
 
@@ -54,8 +54,8 @@
 
 
-/* the interval in which the user/group cache is flushed (in ms) */
-#define THUNAR_USER_MANAGER_FLUSH_INTERVAL (10 * 60 * 1000)
+/* the interval in which the user/group cache is flushed (in seconds) */
+#define THUNAR_USER_MANAGER_FLUSH_INTERVAL (10 * 60)
 
 


More information about the Xfce4-commits mailing list